.. pyqode documentation master file, created by
   sphinx-quickstart on Sun Oct 12 18:28:02 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyqode.python's API reference documentation!
=======================================================

**pyqode.python** adds **python** support to `pyQode`_ (code completion,
calltips, ...).

- `Issue tracker`_
- `Wiki`_
- `API reference`_
- `Contributing`_
- `Changelog`_
- `Screenshots`_

This documentation contains the **API reference documentation** and the
**official examples**.

.. note:: We recommend you to start with the `Readme`_ and the `Wiki`_
          before reading this document


API reference:
==============

.. toctree::
   :maxdepth: 3

   pyqode.python

Examples:
=========

.. toctree::
   :maxdepth: 2

   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _Readme: https://github.com/pyQode/pyqode.python/blob/master/README.rst
.. _Screenshots: https://github.com/pyQode/pyQode/wiki/Screenshots-and-videos#pyqodepython-screenshots
.. _Issue tracker: https://github.com/pyQode/pyQode/issues
.. _Wiki: https://github.com/pyQode/pyQode/wiki
.. _API reference: https://pythonhosted.org/pyqode.python/
.. _pyQode: https://github.com/pyQode/pyQode
.. _Jedi: https://github.com/davidhalter/jedi
.. _Changelog: https://github.com/pyQode/pyqode.python/blob/master/CHANGELOG.rst
.. _Contributing: https://github.com/pyQode/pyqode.python/blob/master/CONTRIBUTING.rst
